@@ -16,7 +16,7 @@ use Rose::DB::Constants qw(IN_TRANSACTION);
 use Rose::DB::Object::Util 
   qw(row_id lazy_column_values_loaded_key has_modified_columns);
 
-our $VERSION = '0.753';
+our $VERSION = '0.754';
 
 our $Debug = 0;
 
@@ -160,6 +160,11 @@ sub load
 
   unless(@key_values == @key_columns)
   {
+    my $alt_columns;
+
+    # Prefer unique keys where we have defined values for all
+    # key calumns, but fall back to teh first unique key found 
+    # where we have at least one defined value.
     foreach my $cols ($meta->unique_keys_column_names)
     {
       my $defined = 0;
@@ -168,12 +173,22 @@ sub load
       @key_values  = map { $defined++ if(defined $_); $_ } 
                      map { $self->$_() } @key_methods;
 
-      if($defined)
+      if($defined == @key_columns)
       {
         $found_key = 1;
-        $null_key  = 1  unless($defined == @key_columns);
         last;
       }
+
+      $alt_columns ||= $cols  if($defined);
+    }
+
+    if(!$found_key && $alt_columns)
+    {
+      @key_columns = @$alt_columns;
+      @key_methods = map { $meta->column_accessor_method_name($_) }  @key_columns;
+      @key_values  = map { $self->$_() } @key_methods;
+      $null_key    = 1;
+      $found_key   = 1;
     }
 
     unless($found_key)
@@ -503,7 +518,7 @@ sub save
           $code->() or die $self->error;
         }
       }
-      
+
       if($cascade)
       {
         foreach my $fk ($meta->foreign_keys)
@@ -546,7 +561,7 @@ sub save
           next  if($todo->{'rel'}{$rel->name}{'set'});
 
           my $related_objects = $rel->object_has_related_objects($self) || next;
-          
+
           foreach my $related_object (@$related_objects)
           {
             $Debug && warn "$self - save related ", $rel->name, " - $related_object\n";
@@ -1883,6 +1898,8 @@ Load a row from the database table, initializing the object with the values from
 
 Returns true if the row was loaded successfully, undef if the row could not be loaded due to an error, or zero (0) if the row does not exist.  The true value returned on success will be the object itself.  If the object L<overload>s its boolean value such that it is not true, then a true value will be returned instead of the object itself.
 
+When loading based on a unique key, unique keys are considered in the order in which they were defined in the L<metadata|/meta> for this class.  If the object has defined values for every column in a unique key, then that key is used.  If no such keys are found, then the first key for which the object has at least one defined value is used.
+
 PARAMS are optional name/value pairs.  Valid PARAMS are:
 
 =over 4
